import nodeinfo
import aiohttp
import asyncio
import sys

async def main():
    """Read a hostname from arguments
    and print it's nodeinfo
    """

    for host in sys.argv[1:]:

        print(await nodeinfo.load(host))

if __name__ == "__main__":
    loop = asyncio.get_event_loop()
    loop.run_until_complete(main())



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['nodeinfo']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.8.3,<4.0.0', 'requests>=2.28.2,<3.0.0']

setup_kwargs = {
    'name': 'pynodeinfo',
    'version': '0.1.1',
    'description': 'Python Nodeinfo Library',
    'long_description': '# pynodeinfo\n\nPython NodeInfo library implemented with poetry.',
    'author': 'CSDUMMI',
    'author_email': 'csdummi.misquality@simplelogin.co',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



import aiohttp
import asyncio

async def load(host):
    """
    Load the nodeinfo of the given host

    Raises:
    - ValueError if the provided host does not implement the Nodeinfo protocol
    - IOError if the node info protocol is implemented incorrectly.
    """

    async with aiohttp.ClientSession() as session:
        nodeinfo_uri = await get_nodeinfo_uri(host, session)

        async with session.get(nodeinfo_uri) as response:

            if not response.ok:
                raise ValueError("NodeInfo Endpoint returns an error: " + response.status)

            if response.content_type != "application/json":
                raise IOError("NodeInfo endpoint returned content of type: " + response.content_type)

            info = await response.json()
            return info

async def get_nodeinfo_uri(host, session):
    async with session.get("https://" + host + "/.well-known/nodeinfo") as response:

        if not response.ok or response.content_type != "application/json":
            raise ValueError("Host does not provide nodeinfo")

        info = await response.json()

        return get_max_uri(info["links"])

def get_max_uri(links):

    max = links[0]
    max_version = max["rel"].split("/")[-1].split(".")

    for link in links[1:]:
        version = link["rel"].split("/")[-1].split(".")
        if version[0] > max_version[0]:
            max = link
            continue
        if version[1] > max_version[1]:
            max = link
            continue

    return max["href"]

